@@ -4,11 +4,13 @@ use regex::{
 	Regex,
 	RegexBuilder,
 };
+use secrecy::SecretString;
 use serde::{
 	Deserialize,
 	Serialize,
 };
 use std::ffi::OsStr;
+use std::fmt;
 use std::fs;
 use std::path::Path;
 
@@ -28,6 +30,9 @@ pub struct Config {
 	/// Configuration values about git.
 	#[serde(default)]
 	pub git:       GitConfig,
+	/// Configuration values about remote.
+	#[serde(default)]
+	pub remote:    RemoteConfig,
 }
 
 /// Changelog configuration.
@@ -84,9 +89,58 @@ pub struct GitConfig {
 	pub limit_commits:            Option<usize>,
 }
 
+/// Remote configuration.
+#[derive(Default, Debug, Clone, Serialize, Deserialize)]
+pub struct RemoteConfig {
+	/// GitHub remote.
+	pub github: Remote,
+}
+
+/// A single remote.
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
+pub struct Remote {
+	/// Owner of the remote.
+	pub owner: String,
+	/// Repository name.
+	pub repo:  String,
+	/// Access token.
+	#[serde(skip_serializing)]
+	pub token: Option<SecretString>,
+}
+
+impl fmt::Display for Remote {
+	fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+		write!(f, "{}/{}", self.owner, self.repo)
+	}
+}
+
+impl PartialEq for Remote {
+	fn eq(&self, other: &Self) -> bool {
+		self.to_string() == other.to_string()
+	}
+}
+
+impl Remote {
+	/// Constructs a new instance.
+	pub fn new<S: Into<String>>(owner: S, repo: S) -> Self {
+		Self {
+			owner: owner.into(),
+			repo:  repo.into(),
+			token: None,
+		}
+	}
+
+	/// Returns `true` if the remote has an owner and repo.
+	pub fn is_set(&self) -> bool {
+		!self.owner.is_empty() && !self.repo.is_empty()
+	}
+}
+
 /// Parser for grouping commits.
-#[derive(Debug, Clone, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 pub struct CommitParser {
+	/// SHA1 of the commit.
+	pub sha:           Option<String>,
 	/// Regex for matching the commit message.
 	#[serde(with = "serde_regex", default)]
 	pub message:       Option<Regex>,
@@ -226,4 +280,16 @@ mod test {
 		);
 		Ok(())
 	}
+
+	#[test]
+	fn remote_config() {
+		let remote1 = Remote::new("abc", "xyz1");
+		let remote2 = Remote::new("abc", "xyz2");
+		assert!(!remote1.eq(&remote2));
+		assert_eq!("abc/xyz1", remote1.to_string());
+		assert!(remote1.is_set());
+		assert!(!Remote::new("", "test").is_set());
+		assert!(!Remote::new("test", "").is_set());
+		assert!(!Remote::new("", "").is_set());
+	}
 }
